pub struct Session<User> { /* private fields */ }Expand description
An authenticated session for a user.
Sessions are created by Authentication::login,
inserted into request extensions by the authentication middleware, and can be
extracted by Axum handlers when the axum feature is enabled.
Implementations